# Deep learning library based on openmmlab
```
python -m build
twine upload dist/*
pypi-AgEIcHlwaS5vcmcCJDkxOWY1ZTA3LWU1MTgtNGYxMS1iMmJmLWRlYTYzNjZkMzcwMAACKlszLCIyMzFmY2FiNi0zNDhlLTQ2ZGEtYmMxMC0wOWQ0ZDc0Y2Y3ODAiXQAABiDbR9LmnHBG5OazaeMY5R4-xvHAIcTuBgfF3gCTblmrRg
```